@@ -3,9 +3,7 @@
  *   Copyright (C) 1997, 1998 Worldvisions Computer Technology, Inc.
  * 
  * A WvSplitStream uses two different file descriptors: one for input
- * and another for output.  Because of this, simultaneous select()
- * for read and write will not work, and select() via WvStreamList
- * only works for read.
+ * and another for output.
  * 
  * This is primarily used for the combined stdin/stdout stream.
  */
@@ -27,13 +25,17 @@ public:
     virtual bool isok() const;
     virtual bool select_setup(fd_set &r, fd_set &w, fd_set &x, int &max_fd,
 			      bool readable, bool writable, bool isexception);
-    virtual bool select(time_t msec_timeout, bool readable = true,
-			bool writable = false, bool isexception = false);
     int getrfd() const
         { return rfd; }
     int getwfd() const
         { return wfd; }
     
+    // noread() closes the rfd and makes this stream no longer valid for
+    // reading.  nowrite() closes wfd and makes it no longer valid for
+    // writing.
+    void noread();
+    void nowrite();
+    
 protected:
     int rfd, wfd;
     int in_progress;
